// SPDX-License-Identifier: MPL-2.0

//! [`Table`].

use crate::prelude::*;

def_subcontrol!(
    docs: "


        # Examples

        ```no_run
        // TODO
        ```
    ",
    ty: Table,
    handle: uiTable,
);
